@@ -1,7 +1,7 @@
 """
 Type annotations for secretsmanager service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/)
 
 Usage::
 
@@ -84,7 +84,7 @@ class Exceptions:
 class SecretsManagerClient(BaseClient):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/)
     """
 
     meta: ClientMeta
@@ -95,7 +95,7 @@ class SecretsManagerClient(BaseClient):
         SecretsManagerClient exceptions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#exceptions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
@@ -103,7 +103,7 @@ class SecretsManagerClient(BaseClient):
         Check if an operation can be paginated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#can_paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#can_paginate)
         """
 
     def cancel_rotate_secret(self, *, SecretId: str) -> CancelRotateSecretResponseTypeDef:
@@ -112,7 +112,7 @@ class SecretsManagerClient(BaseClient):
         cancels the rotation.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#cancel_rotate_secret)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#cancel_rotate_secret)
         """
 
     def create_secret(
@@ -122,7 +122,7 @@ class SecretsManagerClient(BaseClient):
         ClientRequestToken: str = ...,
         Description: str = ...,
         KmsKeyId: str = ...,
-        SecretBinary: Union[bytes, IO[bytes], StreamingBody] = ...,
+        SecretBinary: Union[str, bytes, IO[Any], StreamingBody] = ...,
         SecretString: str = ...,
         Tags: Sequence["TagTypeDef"] = ...,
         AddReplicaRegions: Sequence["ReplicaRegionTypeTypeDef"] = ...,
@@ -132,7 +132,7 @@ class SecretsManagerClient(BaseClient):
         Creates a new secret.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#create_secret)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#create_secret)
         """
 
     def delete_resource_policy(self, *, SecretId: str) -> DeleteResourcePolicyResponseTypeDef:
@@ -140,7 +140,7 @@ class SecretsManagerClient(BaseClient):
         Deletes the resource-based permission policy attached to the secret.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#delete_resource_policy)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#delete_resource_policy)
         """
 
     def delete_secret(
@@ -154,7 +154,7 @@ class SecretsManagerClient(BaseClient):
         Deletes a secret and all of its versions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#delete_secret)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#delete_secret)
         """
 
     def describe_secret(self, *, SecretId: str) -> DescribeSecretResponseTypeDef:
@@ -162,7 +162,7 @@ class SecretsManagerClient(BaseClient):
         Retrieves the details of a secret.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#describe_secret)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#describe_secret)
         """
 
     def generate_presigned_url(
@@ -176,7 +176,7 @@ class SecretsManagerClient(BaseClient):
         Generate a presigned url given a client, its method, and arguments.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#generate_presigned_url)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#generate_presigned_url)
         """
 
     def get_random_password(
@@ -195,7 +195,7 @@ class SecretsManagerClient(BaseClient):
         Generates a random password.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#get_random_password)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#get_random_password)
         """
 
     def get_resource_policy(self, *, SecretId: str) -> GetResourcePolicyResponseTypeDef:
@@ -204,7 +204,7 @@ class SecretsManagerClient(BaseClient):
         secret.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#get_resource_policy)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#get_resource_policy)
         """
 
     def get_secret_value(
@@ -215,7 +215,7 @@ class SecretsManagerClient(BaseClient):
         from the specified version of a secret, whichever contains content.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#get_secret_value)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#get_secret_value)
         """
 
     def list_secret_version_ids(
@@ -230,7 +230,7 @@ class SecretsManagerClient(BaseClient):
         Lists the versions for a secret.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#list_secret_version_ids)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#list_secret_version_ids)
         """
 
     def list_secrets(
@@ -245,7 +245,7 @@ class SecretsManagerClient(BaseClient):
         .
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#list_secrets)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#list_secrets)
         """
 
     def put_resource_policy(
@@ -255,7 +255,7 @@ class SecretsManagerClient(BaseClient):
         Attaches a resource-based permission policy to a secret.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#put_resource_policy)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#put_resource_policy)
         """
 
     def put_secret_value(
@@ -263,7 +263,7 @@ class SecretsManagerClient(BaseClient):
         *,
         SecretId: str,
         ClientRequestToken: str = ...,
-        SecretBinary: Union[bytes, IO[bytes], StreamingBody] = ...,
+        SecretBinary: Union[str, bytes, IO[Any], StreamingBody] = ...,
         SecretString: str = ...,
         VersionStages: Sequence[str] = ...
     ) -> PutSecretValueResponseTypeDef:
@@ -272,7 +272,7 @@ class SecretsManagerClient(BaseClient):
         secret.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#put_secret_value)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#put_secret_value)
         """
 
     def remove_regions_from_replication(
@@ -283,7 +283,7 @@ class SecretsManagerClient(BaseClient):
         from the Regions you specify.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#remove_regions_from_replication)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#remove_regions_from_replication)
         """
 
     def replicate_secret_to_regions(
@@ -297,7 +297,7 @@ class SecretsManagerClient(BaseClient):
         Replicates the secret to a new Regions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#replicate_secret_to_regions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#replicate_secret_to_regions)
         """
 
     def restore_secret(self, *, SecretId: str) -> RestoreSecretResponseTypeDef:
@@ -306,7 +306,7 @@ class SecretsManagerClient(BaseClient):
         stamp.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#restore_secret)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#restore_secret)
         """
 
     def rotate_secret(
@@ -322,7 +322,7 @@ class SecretsManagerClient(BaseClient):
         Configures and starts the asynchronous process of rotating the secret.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#rotate_secret)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#rotate_secret)
         """
 
     def stop_replication_to_replica(
@@ -333,7 +333,7 @@ class SecretsManagerClient(BaseClient):
         the replica to a primary secret in the replica Region.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#stop_replication_to_replica)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#stop_replication_to_replica)
         """
 
     def tag_resource(self, *, SecretId: str, Tags: Sequence["TagTypeDef"]) -> None:
@@ -341,7 +341,7 @@ class SecretsManagerClient(BaseClient):
         Attaches tags to a secret.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#tag_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#tag_resource)
         """
 
     def untag_resource(self, *, SecretId: str, TagKeys: Sequence[str]) -> None:
@@ -349,7 +349,7 @@ class SecretsManagerClient(BaseClient):
         Removes specific tags from a secret.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#untag_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#untag_resource)
         """
 
     def update_secret(
@@ -359,14 +359,14 @@ class SecretsManagerClient(BaseClient):
         ClientRequestToken: str = ...,
         Description: str = ...,
         KmsKeyId: str = ...,
-        SecretBinary: Union[bytes, IO[bytes], StreamingBody] = ...,
+        SecretBinary: Union[str, bytes, IO[Any], StreamingBody] = ...,
         SecretString: str = ...
     ) -> UpdateSecretResponseTypeDef:
         """
         Modifies the details of a secret, including metadata and the secret value.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#update_secret)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#update_secret)
         """
 
     def update_secret_version_stage(
@@ -381,7 +381,7 @@ class SecretsManagerClient(BaseClient):
         Modifies the staging labels attached to a version of a secret.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#update_secret_version_stage)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#update_secret_version_stage)
         """
 
     def validate_resource_policy(
@@ -392,11 +392,11 @@ class SecretsManagerClient(BaseClient):
         access to your secret.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#validate_resource_policy)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#validate_resource_policy)
         """
 
     def get_paginator(self, operation_name: Literal["list_secrets"]) -> ListSecretsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#get_paginator)
         """
