@@ -1,7 +1,7 @@
 """
 Type annotations for secretsmanager service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/type_defs/)
 
 Usage::
 
@@ -13,10 +13,9 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Dict, List, Sequence, Union
+from typing import IO, Any, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
-from typing_extensions import NotRequired
 
 from .literals import FilterNameStringTypeType, SortOrderTypeType, StatusTypeType
 
@@ -111,7 +110,7 @@ _OptionalCreateSecretRequestRequestTypeDef = TypedDict(
         "ClientRequestToken": str,
         "Description": str,
         "KmsKeyId": str,
-        "SecretBinary": Union[bytes, IO[bytes], StreamingBody],
+        "SecretBinary": Union[str, bytes, IO[Any], StreamingBody],
         "SecretString": str,
         "Tags": Sequence["TagTypeDef"],
         "AddReplicaRegions": Sequence["ReplicaRegionTypeTypeDef"],
@@ -418,7 +417,7 @@ _OptionalPutSecretValueRequestRequestTypeDef = TypedDict(
     "_OptionalPutSecretValueRequestRequestTypeDef",
     {
         "ClientRequestToken": str,
-        "SecretBinary": Union[bytes, IO[bytes], StreamingBody],
+        "SecretBinary": Union[str, bytes, IO[Any], StreamingBody],
         "SecretString": str,
         "VersionStages": Sequence[str],
     },
@@ -671,7 +670,7 @@ _OptionalUpdateSecretRequestRequestTypeDef = TypedDict(
         "ClientRequestToken": str,
         "Description": str,
         "KmsKeyId": str,
-        "SecretBinary": Union[bytes, IO[bytes], StreamingBody],
+        "SecretBinary": Union[str, bytes, IO[Any], StreamingBody],
         "SecretString": str,
     },
     total=False,
